% Written by: Ahmad Kolahi
%
clear all         % Remove items from workspace, freeing up system memory
clc               % Clear Command Window
tst = 2;          % Total Simulation Time
sti = 0.02;       % Simulation Times Intervals
pti = 0.2;        % Pulse Times Intervals
K = 1.38*10^-23   % Boltzmann's Constant
M = 107.88
m = 17.9*10^-23
T = 1000
Pe = 1.3*10^-6
Gama = 3.513*10^22*Pe/sqrt(M*T)   % Particles Generation Rate
RF = 5 * 10^-13;                      % Reduction Factor of Gama
n = RF * Gama;                    % No. of Particles
V = sqrt(2*K*T/m)                 % Velocity of the particles
sos = tst/sti;                    % no. of Steps Of Simulation
sop = tst/pti;                    % no. of Steps Of Pulse

for nt = 1:sop                     %Random Positing Procedure
    x0(nt,:) = rand(1,n)-0.5;
    y0(nt,:) = rand(1,n)-0.5;
    phi(nt,:) = rand(1,n)*2*pi;
    tet(nt,:) = rand(1,n)*0.5*pi;
end
t = 20;
x = x0(1,:) + V*sin(tet(1,:)).*cos(phi(1,:))*t;  %Equations of Motion
y = y0(1,:) + V*sin(tet(1,:)).*sin(phi(1,:))*t;
z = V*cos(tet(1,:))*t;

nn = (x>-5)&(x<5)&(y>-5)&(y<5)&(z>20);   % Contact Codition Check
j = 100*sum(nn)/n      % Percent of Contact particles

for i=-5:4  % Procedure for plotting the surface
    for j=-5:4
        a = (x>i)&(x<i+1)&(y>j)&(y<j+1);
        sm = sum(a)         % Sum of array elements
        s(i+6,j+6) = sm/n;
    end
end
surf(100*s)   % 3-D shaded surface plot

su = 20*ones(11);
sd = -100*ones(11);
sd(5,5)= 0;
sd(5,6)= 0;
sd(6,5)= 0;
sd(6,6)= 0;

for j = 1:sos
    t = sti*j;
    hold on    %Hold current graph in the figure
    cla        %Clear current axes
    surf(su);   % 3-D shaded surface plot
    surf(sd);   % 3-D shaded surface plot
    for nt=1:sop
        dnt = (nt-1)*pti;
        if t>dnt
            x = x0(nt,:) + V*sin(tet(nt,:)).*cos(phi(nt,:))*(t-dnt);
            y = y0(nt,:) + V*sin(tet(nt,:)).*sin(phi(nt,:))*(t-dnt);
            z = V*cos(tet(nt,:))*(t-dnt);
            for i = 1:n
                if z(i)<20
                    plot3(x(i)+5.5,y(i)+5.5,z(i),'.')      % 3-D line plot
                end
            end
        end
    end
    axis([1  11  1  11  0  20])
    F(j) = getframe;   % Get movie frame
end
%movie(F,1)                     % Play recorded movie frames
%movie2avi(F,['c:\mont2.avi'])  % Create an Audio/Video Interleaved (AVI) movie from MATLAB movie

